@@ -1,7 +1,7 @@
 import pytest
 import os
-import filecmp
 import subprocess
+import time
 
 
 def pytest_addoption(parser):
@@ -20,7 +20,6 @@ def pytest_sessionstart(session):
     for root, dirs, files in os.walk(path):
         for file in files:
             file_name.append(file)
-    print(file_name)
     if 'requirements.txt' in file_name:
         libs = os.popen('pip list').read()
         with open('libs_backup.txt', 'w')as f:
@@ -37,18 +36,29 @@ def pytest_sessionstart(session):
                     with open('doc.txt', 'a')as f:
                         f.write(f'{line[0]}=={line[len(line) - 1]}\n')
         os.remove('libs_backup.txt')
+        lib_list = []
         try:
-            status = filecmp.cmp('doc.txt', 'requirements.txt')
-            if status:
-                print('No difference in current version')
+            with open('requirements.txt','r')as fr:
+                with open('libs_backup.txt','r')as fd:
+                    requirments = fr.readlines()
+                    doc = fd.read()
+                    for fr_line in requirments:
+                        if fr_line not in doc:
+                            lib_list.append(fr_line)
+            time.sleep(3)
+            if lib_list != 0:
+                print('The following versions are found missing')
+                print(lib_list)
+                for lib in lib_list:
+                    print(f'Installing {lib}, please wait')
+                    cmd = f'pip install -i http://pypi.douban.com/simple/ {lib}'
+                    output = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
+                    for line in output.stdout:
+                        print(line)
             else:
-                print('Installing differential version, please wait')
-                cmd = 'pip install -r requirements.txt -i http://pypi.douban.com/simple/ --trusted-host pypi.douban.com'
-                output = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
-                for line in output.stdout:
-                    print(line)
+                print('No difference in current version')
+
         finally:
             os.remove('doc.txt')
-            pass
     else:
         raise ('Not found requirements.txt')
